
; Simple program that takes a Julian date as an input and returns the
; Mission Phase abbreviation, Phase name, target code, target name and
; target type for use in the PDS label files. Most of the returned
; values for a given phase are specified by RSOC.
;
; v. 1 2006-10-18  A.J. Steffl
; v. 2 2007-01-22  AJS: update to include observations through end of
;  2006 
; v. 3 2007-03-05 AJS: Update to include observations through end of
; MSB and Jupiter observations
PRO ralice_target, levelnum, start_et, phaseabbrev, phasename, target_id, target_name, $
                   target_type, dataset_target_name, spice_target_name, target_desc

;initialize target description variable
target_desc = ''

CSPICE_UTC2ET, '2004-03-02T0', leop_beg_et  ; Launch
CSPICE_UTC2ET, '2004-03-05T0', cvp1_beg_et  ; Commissioning part 1
CSPICE_UTC2ET, '2004-06-07T0', cr1_beg_et   ; Cruise 1
CSPICE_UTC2ET, '2004-09-06T0', cvp2_beg_et  ; Commissioning part 2
CSPICE_UTC2ET, '2004-10-17T0', ear1_beg_et  ; Earth Swing-by 1
CSPICE_UTC2ET, '2005-04-05T0', cr2_beg_et   ; Cruise 2
CSPICE_UTC2ET, '2006-07-29T0', mar_beg_et   ; Mars Swing-by
CSPICE_UTC2ET, '2007-05-29T0', cr3_beg_et   ; Cruise 3 
CSPICE_UTC2ET, '2007-09-13T0', ear2_beg_et  ; Earth Swing-by 2
CSPICE_UTC2ET, '2007-12-14T0', cr4_1_beg_et   ; Cruise 4 part 1
CSPICE_UTC2ET, '2007-07-05T0', steins_beg_et  ; Steins flyby 
CSPICE_UTC2ET, '2008-11-06T0', cr4_2_beg_et   ; Cruise 4 part 2
CSPICE_UTC2ET, '2009-09-13T0', ear3_beg_et  ; Earth Swing-by 3

CASE 1 OF
   start_et LT cvp1_beg_et : BEGIN
      phaseabbrev = 'LEOP'
      phasename = '"LAUNCH"'
      target_name = 'CHECKOUT'
      target_id = 'X'
      dataset_target_name = 'CHECK'
      target_type = '"N/A"'
      spice_target_name = '"N/A"'
   END

   start_et LE cr1_beg_et : BEGIN
      phaseabbrev = 'CVP1'
      phasename = '"COMMISSIONING 1"'
      target_id = 'C/CAL/X'
      dataset_target_name = '2002T7/CAL/CHECK'

      CSPICE_UTC2ET, '2004-04-22T21:46:52', cvp1_cal1_beg
      CSPICE_UTC2ET, '2004-04-30T0', lineart7_beg
      CSPICE_UTC2ET, '2004-05-28T0', hd203245_beg
      CSPICE_UTC2ET, '2004-05-28T22', alpha_peg_beg
      CSPICE_UTC2ET, '2004-05-29T01:30', alpha_peg_end
      CASE 1 OF 
         start_et GE cvp1_cal1_beg AND start_et LT lineart7_beg : BEGIN
            target_name = 'CALIBRATION'
            target_type = 'CALIBRATION'
            target_desc = 'Sky background'
            spice_target_name = '"N/A"'
          END
         start_et GE lineart7_beg AND start_et LT hd203245_beg : BEGIN
            target_name = '"C/LINEAR (2002 T7)"'
            target_type = 'COMET'
            target_desc = 'C/2002 T7 LINEAR'
            spice_target_name = '1000418' ; SPICE doesn't seem to recognize this...
         END
         start_et GE hd203245_beg AND start_et LT alpha_peg_beg : BEGIN
            target_name = 'CALIBRATION'
            target_desc = 'HD 203245'
            target_type = 'CALIBRATION'
            spice_target_name = '"N/A"'
         END
         start_et GE alpha_peg_beg AND start_et LT alpha_peg_end : BEGIN
            target_name = 'CALIBRATION'
            target_desc = 'Alpha Peg'
            target_type = 'CALIBRATION'
            spice_target_name = '"N/A"'
         END
         ELSE : BEGIN
            target_name = 'CHECKOUT'
            target_type = '"N/A"'
            spice_target_name = '"N/A"'
            target_desc = 'Instrument Checkout'
         END
      ENDCASE
   END

   start_et LE cvp2_beg_et : BEGIN
      phaseabbrev = 'CR1'
      phasename = '"CRUISE 1"'
      target_name = 'CHECKOUT'
      target_type = '"N/A"'
      target_id = 'X'
      dataset_target_name = 'CHECK'
      spice_target_name = '"N/A"'
      target_desc = 'Instrument Checkout'
   END

   start_et LE ear1_beg_et : BEGIN
      phaseabbrev = 'CVP2'
      phasename = '"COMMISSIONING 2"'
      target_id = 'CAL/X'
      dataset_target_name = 'CAL/CHECK'

      CSPICE_UTC2ET,'2004-09-27T04', gamma_grus_beg
      CSPICE_UTC2ET,'2004-09-27T08', gamma_grus_end
      CSPICE_UTC2ET,'2004-10-04T05', alpha_grus_beg
      CSPICE_UTC2ET,'2004-10-04T10', alpha_grus_end
      CASE 1 OF
         start_et GE gamma_grus_beg AND start_et LT gamma_grus_end : BEGIN
            target_name = 'CALIBRATION'
            target_desc = 'Gamma Gru'
            target_type = 'CALIBRATION'
            spice_target_name = '"N/A"'
         END
         start_et GE alpha_grus_beg AND start_et LT alpha_grus_end : BEGIN
            target_name = 'CALIBRATION'
            target_desc = 'Alpha Gru'
            target_type = 'CALIBRATION'
            spice_target_name = '"N/A"'
         END
         ELSE : begin
            target_name = 'CHECKOUT'
            target_type = '"N/A"'
            spice_target_name = '"N/A"'
            target_desc = 'Instrument Checkout'
         END
      ENDCASE
   END

   start_et LE cr2_beg_et : BEGIN
      phaseabbrev = 'EAR1'
      phasename = '"EARTH SWING-BY 1"'
      target_name = 'CALIBRATION'
      target_type = 'CALIBRATION'
      CASE levelnum OF
         '2': BEGIN 
            dataset_target_name = 'CAL/CHECK'
            target_id = 'CAL/X'
         END
         '3': BEGIN
            dataset_target_name = 'CAL'
            target_id = 'CAL'
         END
      ENDCASE

;     spice_target_name = 'MOON'

      CSPICE_UTC2ET,'2005-03-08T06:47:00', sky1_beg
      CSPICE_UTC2ET,'2005-03-08T07:15:00', sky1_end
      CSPICE_UTC2ET,'2005-03-08T09:17:00', sky2_beg
      CSPICE_UTC2ET,'2005-03-08T09:45:00', sky2_end
      CSPICE_UTC2ET,'2005-03-09T04:45:00', moonscatter_beg
      CSPICE_UTC2ET,'2005-03-09T09:44:01', moonscatter_end

      CASE 1 OF
         start_et GE sky1_beg AND start_et LT sky1_end : BEGIN
            target_desc = 'Sky background'
            spice_target_name = '"N/A"'
         END
         start_et GE sky2_beg AND start_et LT sky2_end : BEGIN
            target_desc = 'Sky background'
            spice_target_name = '"N/A"'
         END
         start_et GE moonscatter_beg AND start_et LT moonscatter_end : BEGIN
            target_desc = 'Lunar scattered light'
            spice_target_name = 'MOON'
            target_name = 'MOON'
            target_type = 'SATELLITE'
         END
         ELSE : begin
            target_desc = 'Moon'
            spice_target_name = 'MOON'
         END
      ENDCASE
   END

   start_et LE mar_beg_et : BEGIN
      phaseabbrev = 'CR2'
      phasename = '"CRUISE 2"'
      target_id = 'C/CAL/X'
      dataset_target_name = '9P/CAL/CHECK'

      CSPICE_UTC2ET,'2005-06-27T00', rho_leo_beg
      CSPICE_UTC2ET,'2005-06-28T23', tempel1_beg
      CSPICE_UTC2ET,'2005-07-14T05', tempel1_end

      CASE 1 OF
         start_et GE rho_leo_beg AND start_et LT tempel1_beg : BEGIN
            target_name = 'CALIBRATION'
            target_desc = 'Rho Leo'
            target_type = 'CALIBRATION'
            spice_target_name = '"N/A"'
         END
         start_et GE tempel1_beg AND start_et LT tempel1_end : BEGIN
            target_name = '"9P/TEMPEL 1 (1867 G1)"'
            target_type = 'COMET'
            spice_target_name = 'TEMPEL 1'
            target_desc = 'Comet 9P/Tempel 1 (1867 G1)'
         END
         ELSE : BEGIN
            target_name = 'CHECKOUT'
            target_type = '"N/A"'
            spice_target_name = '"N/A"'
            target_desc = 'Instrument Checkout'
         END
      ENDCASE
   END

   start_et LE cr3_beg_et : BEGIN
      phaseabbrev = 'MARS'
      phasename = '"MARS SWING-BY"'
      CASE levelnum OF
         '2': BEGIN 
            dataset_target_name = 'CAL/CHECK/JUPITER/MARS'
            target_id = 'CAL/J/M/X'
         END
         '3': BEGIN
            dataset_target_name = 'CAL/JUPITER/MARS'
            target_id = 'CAL/J/M'
         END
      ENDCASE

      CSPICE_UTC2ET, '2006-12-03T01:15:00.00', mars1_beg
      CSPICE_UTC2ET, '2006-12-03T05:30:00.00', mars1_end
      CSPICE_UTC2ET, '2006-12-03T06:00:00.00', gammagru1_beg
      CSPICE_UTC2ET, '2006-12-03T12:29:00.00', gammagru1_end
      CSPICE_UTC2ET, '2006-12-03T13:15:00.00', sky1_beg
      CSPICE_UTC2ET, '2006-12-04T16:20:30.00', sky1_end
      CSPICE_UTC2ET, '2006-12-10T03:00:00.00', saturn_beg
      CSPICE_UTC2ET, '2006-12-10T06:20:30.00', saturn_end
      CSPICE_UTC2ET, '2006-12-10T17:00:00.00', vega_beg
      CSPICE_UTC2ET, '2006-12-10T19:30:00.00', vega_end
      CSPICE_UTC2ET, '2006-12-16T09:30:00.00', lac10_beg
      CSPICE_UTC2ET, '2006-12-16T12:05:30.00', lac10_end
      CSPICE_UTC2ET, '2006-12-17T01:45:00.00', zetacas_beg
      CSPICE_UTC2ET, '2006-12-17T06:14:00.00', zetacas_end
      CSPICE_UTC2ET, '2007-02-23T12:00:00.00', alphalyr_beg
      CSPICE_UTC2ET, '2007-02-23T14:05:30.00', alphalyr_end
      CSPICE_UTC2ET, '2007-02-24T17:59:12.00', mars_swingby_beg
      CSPICE_UTC2ET, '2007-02-24T17:59:12.00', mars_swingby_end
      CSPICE_UTC2ET, '2007-02-28T03:45:00.00', jupiter_beg
      CSPICE_UTC2ET, '2007-05-09T17:35:30.00', jupiter_end

      CASE 1 OF
         start_et GE mar_beg_et AND start_et LT mars1_beg : BEGIN
            target_name = 'CALIBRATION'
            target_type = 'CALIBRATION'
            target_desc = 'HV and Discriminator calibration'
            spice_target_name = '"N/A"'
         END
         start_et GE mars1_beg AND start_et LT mars1_end : BEGIN
            target_name = 'MARS'
            target_type = 'PLANET'
            target_desc = 'Mars'
            spice_target_name = 'MARS'
         END
         start_et GE gammagru1_beg AND start_et LT gammagru1_end : BEGIN
            target_name = 'CALIBRATION'
            target_type = 'CALIBRATION'
            target_desc = 'Gamma Gru'
            spice_target_name = '"N/A"'
         END
         start_et GE sky1_beg AND start_et LT sky1_end : BEGIN
            target_name = 'CALIBRATION'
            target_type = 'CALIBRATION'
            target_desc = 'Sky background'
            spice_target_name = '"N/A"'
         END
         start_et GE saturn_beg AND start_et LT saturn_end : BEGIN
            target_name = 'SATURN'
            target_type = 'PLANET'
            target_desc = 'Saturn'
            spice_target_name = 'SATURN'
         END
         start_et GE vega_beg AND start_et LT vega_end : BEGIN
            target_name = 'CALIBRATION'
            target_type = 'CALIBRATION'
            target_desc = 'Vega'
            spice_target_name = '"N/A"'
         END
         start_et GE lac10_beg AND start_et LT lac10_end : BEGIN
            target_name = 'CALIBRATION'
            target_type = 'CALIBRATION'
            target_desc = '10 Lac'
            spice_target_name = '"N/A"'
         END
         start_et GE zetacas_beg AND start_et LT zetacas_end : BEGIN
            target_name = 'CALIBRATION'
            target_type = 'CALIBRATION'
            target_desc = 'Zeta Cas'
            spice_target_name = '"N/A"'
         END
         start_et GE alphalyr_beg AND start_et LT alphalyr_end : BEGIN
            target_name = 'CALIBRATION'
            target_type = 'CALIBRATION'
            target_desc = 'Alpha Lyr'
            spice_target_name = '"N/A"'
         END
         start_et GE mars_swingby_beg AND start_et LT mars_swingby_end : BEGIN
            target_name = 'MARS'
            target_type = 'PLANET'
            target_desc = 'Mars'
            spice_target_name = 'MARS'
         END
         start_et GE jupiter_beg AND start_et LT jupiter_end : BEGIN
            target_name = 'JUPITER'
            target_type = 'PLANET'
            target_desc = 'Jovian aurora and Io plasma torus'
            spice_target_name = 'JUPITER'
         END
         ELSE : BEGIN
            target_name = 'MARS'
            target_type = 'PLANET'
            target_desc = 'Mars'
            spice_target_name = 'MARS'
         END
      ENDCASE
   END

   start_et GT ear2_beg_et : BEGIN
      phaseabbrev = 'CR3'
      phasename = '"CRUISE 3"'
      target_id = 'CAL'
      target_name = 'CALIBRATION'
      target_type = '"CALIBRATION"'
      dataset_target_name = 'CAL'
      spice_target_name = '"N/A"'
      target_desc = 'Alice calibration observation'

      CSPICE_UTC2ET, '2007-09-13T05:00:00.00', vega_beg
      CSPICE_UTC2ET, '2007-09-16T18:00:00.00', vega_end
      CSPICE_UTC2ET, '2007-09-16T21:00:00.00', scat_light_beg
      CSPICE_UTC2ET, '2007-09-17T08:50:00.00', scat_light_end
      CSPICE_UTC2ET, '2007-09-23T10:00:00.00', wd_beg
      CSPICE_UTC2ET, '2007-09-23T15:30:00.00', wd_end

      CASE 1 OF
         start_et GE vega_beg AND start_et LT vega_end : target_desc = 'Vega'
         start_et GE scat_light_beg AND start_et LT scat_light_end : $
           target_desc = 'Solar scattered light test'
         start_et GE wd_beg AND start_et LT wd_end : target_desc = 'HD 93521'
         ELSE:
      ENDCASE
   END

   ELSE:BEGIN
      print, '% RALICE_TARGET: Input time not within known phases of the Rosetta Mission'
      phaseabbrev = 'UNK'
      phasename = 'UNK'
      target_id = 'UNK'
      target_name = 'UNK'
      target_type = 'UNK'
      dataset_target_name = 'X'
      spice_target_name = '"N/A"'
      target_desc = 'Unknown'
   END

ENDCASE

END

;            target_name = '"(2867) STEINS"'
;            target_type = 'ASTEROID'
;            spice_target_name = ''
;            target_desc = 'Asteroid (2867) Steins'

;["67P/CHURYUMOV-GERASIMENKO (1969 R1)","COMET","67P","C"]
;["(2867) STEINS", "ASTEROID", "STEINS", "A"]
;["(21) LUTETIA", "ASTEROID", "LUTETIA", "A"]
;["EARTH", "PLANET", "EARTH", "E"]
;["MARS", "PLANET", "MARS", "M"]
;["CALIBRATION", "CALIBRATION", "CAL", "CAL"]
;["CHECKOUT", "N/A", "CHECK", "X"]
;["INTERPLANETARY DUST", "DUST", "DUST", "D"]
;["INTERSTELLAR DUST", "DUST", "DUST", "D"]
;["METEOROID STREAM", "DUST", "DUST", "D"]
;["SOLAR WIND", "SOLAR SYSTEM", "SW", "SS"]
;["9P/TEMPEL 1 (1867 G1)", "COMET", "9P", "C"]
;["C/LINEAR (2002 T7)", "COMET", "2002T7","C"]
